#!/usr/bin/env python

import math

width = 660
center_x = width / 2
center_y = width / 2

def calc_bit_len(radius, length):
  circum = 2 * math.pi * radius
  segment = 2 * math.pi * (float(length) / float(circum))

  return segment

def calc_byte_len(radius, length, data):
  header = calc_bit_len(radius, length)
  one = header / 2
  zero = header / 4
  segment = 0

  for bit in range(0, 8):
    if (data & 0x80) == 0: segment += zero + zero
    else: segment += one + zero

  return segment

def draw_block(out, start, radius, length, track):
  circum = 2 * math.pi * radius
  segment = 2 * math.pi * (float(length) / float(circum))

  x0 = center_x + int(radius * math.cos(start))
  y0 = center_y + int(radius * math.sin(start))

  x1 = center_x + int((radius - 50) * math.cos(start))
  y1 = center_y + int((radius - 50) * math.sin(start))

  x2 = center_x + int((radius - 50) * math.cos(start + segment))
  y2 = center_y + int((radius - 50) * math.sin(start + segment))

  x3 = center_x + int(radius * math.cos(start + segment))
  y3 = center_y + int(radius * math.sin(start + segment))

  svg = "<polyline points=\"" + \
    str(x0) + "," + str(y0) + " " + \
    str(x1) + "," + str(y1) + " " + \
    str(x2) + "," + str(y2) + " " + \
    str(x3) + "," + str(y3) + " " + \
    str(x0) + "," + str(y0) + \
    "\" stroke=\"black\" />\n"

  #if (track & 1) == 1:
  #  out.write(svg)

  out.write(svg)

  return segment

# ------------------------------ fold here --------------------------------

fp = open("test.txt", "rb")
text = fp.readline().strip()
fp.close()

out = open("disk.svg", "wb")
out.write("<svg xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\">\n")
#out.write("<circle cx=\"" + str(width / 2) + "\" cy=\"" + str(width / 2) + "\" r=\"" + str(width / 2) + "\" stroke=\"black\" fill=\"white\"/>\n")
out.write("<circle cx=\"" + str(width / 2) + "\" cy=\"" + str(width / 2) + "\" r=\"8\" stroke=\"black\" fill=\"black\"/>\n")

header = 50
angle = 0.0
radius = width / 2
track = 0

for letter in text:
  print letter

  data = ord(letter)

  byte_len = calc_byte_len(radius, header, data)

  # If enough bits are written on a track, move to the next track
  if byte_len + angle > 6.00:
    if angle != 0.0:
      angle = 0.0
      radius -= 50 + 15
      if radius <= 100: break
      byte_len = calc_byte_len(radius, header, data)
      track += 1

  if angle == 0.0:
    angle += draw_block(out, angle, radius, header, track)
    #spacer = angle / 3
    spacer = angle / 2
    angle += spacer

  for n in range(0, 8):
    if (data & 0x80) == 0: bit_len = header / 4
    else: bit_len = header / 2

    angle += draw_block(out, angle, radius, bit_len, track)

    angle += spacer
    data <<= 1

out.write("</svg>\n")
out.close()


